import { select, 
        csv, 
        scaleLinear, 
        max, 
        scaleBand, 
        axisLeft,
        axisBottom} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');
const margin = {top: 20, right: 60, bottom: 30, left: 120};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const render = data => {
  
  const xValue = d => d.continent;
  const yValue = d => d.area;
  
  const xScale = scaleBand()
  	.domain(data.map(xValue))
  	.range([0, innerWidth])
  	.padding(0.1);
  
  const yScale = scaleLinear()
  	.domain([0, max(data, yValue)])
  	.range([0, innerHeight].reverse());
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  g.append('g').call(axisLeft(yScale));
  g.append('g').call(axisBottom(xScale))
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  g.selectAll('rect').data(data)
  	.enter().append('rect')
  	.attr('x', d => xScale(xValue(d)))
  	.attr('y', d => yScale(yValue(d)))
  	.attr('height', d => innerHeight - yScale(yValue(d)))
 		.attr('width', xScale.bandwidth());
};

csv('data.csv').then(data => {
  data.forEach(d => {
  	d.area = +d.area;
  })
	render(data);
});













